@@ -1,16 +1,18 @@
 package Business::ID::SIM;
 
-our $DATE = '2019-10-15'; # DATE
-our $VERSION = '0.08'; # VERSION
-
 use 5.010001;
 use warnings;
 use strict;
 
 use DateTime;
 
-require Exporter;
-our @ISA = qw(Exporter);
+use Exporter 'import';
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-11'; # DATE
+our $DIST = 'Business-ID-SIM'; # DIST
+our $VERSION = '0.081'; # VERSION
+
 our @EXPORT_OK = qw(parse_sim);
 
 # legend: S = lack of samples
@@ -96,7 +98,7 @@ Business::ID::SIM - Validate Indonesian driving license number (nomor SIM)
 
 =head1 VERSION
 
-This document describes version 0.08 of Business::ID::SIM (from Perl distribution Business-ID-SIM), released on 2019-10-15.
+This document describes version 0.081 of Business::ID::SIM (from Perl distribution Business-ID-SIM), released on 2024-07-11.
 
 =head1 SYNOPSIS
 
@@ -127,7 +129,7 @@ in the SIM number and all SIM's have the same number.
 
 Usage:
 
- parse_sim(%args) -> [status, msg, payload, meta]
+ parse_sim(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Validate Indonesian driving license number (nomor SIM).
 
@@ -141,16 +143,17 @@ Arguments ('*' denotes required arguments):
 
 Input to be parsed.
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -162,6 +165,51 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 Source repository is at L<https://github.com/perlancar/perl-Business-ID-SIM>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Steven Haryanto
+
+=over 4
+
+=item *
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=item *
+
+Steven Haryanto <steven@masterweb.net>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2019, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-SIM>
@@ -170,15 +218,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2015, 2014, 2013 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
